#
# spec file for package wxsvg
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012-2019 Mariusz Fik <fisiu@opensuse.org>
# Copyright (c) 2012 Stefan Seyfried <seife+obs@b1-systems.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   3
Name:           wxsvg
Version:        1.5.23
Release:        5.5
Summary:        Library to create, manipulate and render SVG files
License:        LGPL-2.1-or-later WITH WxWindows-exception-3.1
URL:            http://wxsvg.sourceforge.net/
Source:         https://prdownloads.sourceforge.net/wxsvg/%{name}-%{version}.tar.bz2
Patch0:         ffmpeg5.patch
Patch1:         wxsvg-fix-missing-include.patch
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  wxGTK3-3_2-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(pangocairo)
# WARNING: needs to build with the same ffmpeg libraries as DVDStyler.
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libswscale)

%description
WxSVG is a C++ library to create, manipulate and render SVG files.

%package -n     lib%{name}%{sover}
Summary:        Library to create, manipulate and render SVG files

%description -n lib%{name}%{sover}
Dynamic libraries from %{name}, as required at runtime.

%package -n     lib%{name}-devel
Summary:        Header files for %{name}
Requires:       %{name} = %{version}
Requires:       lib%{name}%{sover} = %{version}
Requires:       wxGTK3-3_2-devel
Requires:       pkgconfig(expat)
Requires:       pkgconfig(libart-2.0)

%description -n lib%{name}-devel
Include files for developing programs based on %{name}.

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n lib%{name}%{sover}

%files
%doc AUTHORS ChangeLog TODO
%{_bindir}/svgview
%license COPYING

%files -n lib%{name}%{sover}
%{_libdir}/libwxsvg.so.%{sover}
%{_libdir}/libwxsvg.so.%{sover}.*

%files -n lib%{name}-devel
%{_includedir}/wxSVG
%{_includedir}/wxSVGXML
%{_libdir}/libwxsvg.so
%{_libdir}/pkgconfig/libwxsvg.pc

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Mar 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add wxsvg-fix-missing-include.patch: Add a missing include.
- Modernize spec, use make_build and ldconfig_scriptlets macros.
* Mon Aug  1 2022 Dave Plater <davejplater@gmail.com>
- Build with wxGTK3-3_2 to match DVDStyler's needs
* Tue Jul 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add ffmpeg5.patch: Fix build with ffmpeg5, patch from gentoo
  https://gitweb.gentoo.org/repo/gentoo.git/plain/media-libs/wxsvg/files/ffmpeg5.patch?id=d6fd9cfb26299c76be7483cac4451a226ab8e37f
* Thu Apr 14 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.23
  * wxSVGTextElement: added support of text-decoration "underline"
    and "line-through"
* Fri Mar  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(libart-2.0) BuildRequires: The libart backend got
  dropped in version 1.2 (2013).
- Add explicit pkgconfig(cairo) and pkgconfig(pangocairo)
  BuildRequires: align with what configure checks for.
* Wed Apr 22 2020 Luigi Baldoni <aloisio@gmx.com>
- Set correct license
* Wed Apr  8 2020 aloisio@gmx.com
- Update to version 1.5.22
  * wxSVGImage: fixed loading of video frames
  * added support of rgba colors
  version 1.5.21
  * fixed renedring of symbol elements
  * fixed handling of spaces in transform attribute
  * added support of grayscale mask
  * added initial support of switch element
- Dropped Group tag
* Sat Sep 14 2019 Mariusz Fik <fisiu@opensuse.org>
- Update to 1.5.20:
  * added handling of fill-rule
  * added handling of spreadMethod
  * added handling of clipPath
  * added support of dash-offset
  * added support of mask for path element
  * fixed handling of pt units
  * fixed fill pattern with opacity
  * fixed handling of referenced patterns
- Update to 1.5.19:
  * fixed rendering polyline element
  * fixed drawing a cubic Bézier curve if the previous command was not
    an c or s
- Update to 1.5.18:
  * wxFfmpegMediaDecoder: fixed support of ffmpeg 3.4.x
- Update to 1.5.17:
  * wxSVGUseElement: fixed GetBBox() and GetResultBBox()
* Thu Feb 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.16
  * wxFfmpegMediaDecoder.SetPosition(): added parameter
    seekBackward
  version 1.5.15
  * added skia backend (experimental) (thanks to Zicheng Yang)
* Tue Feb 12 2019 bjorn.lie@gmail.com
- No longer force ffmpeg-3 libs during build.
* Fri Aug  3 2018 aloisio@gmx.com
- Update to version 1.5.14
  * fixed calculation of bounding box if viewbox is specified
  * fixed GetResultBBox()
  * wxSVGCanvasImage: added support of data base64 href
* Fri Aug  3 2018 davejplater@gmail.com
- Build with ffmpeg-3 libs to match DVDStyler, see boo#1103008
* Tue Jan 30 2018 jengelh@inai.de
- Replace %%soname by %%sover to better reflect its use.
* Tue Jan 30 2018 aloisio@gmx.com
- Update to version 1.5.13
  * added support of <a> element
  * fixed wxSVGImageElement::GetBBox()
  * fixed wxSVGUseElement::GetBBox()
* Fri Nov 24 2017 aloisio@gmx.com
- Removed overly specific runtime dependency.
* Tue Nov 21 2017 jengelh@inai.de
- Update RPM groups and summaries.
* Sat Nov 18 2017 aloisio@gmx.com
- Update to 1.5.12
- Upstream changes:
  * wxSVGSVGElement: fixed GetIntersectionList()
* Tue Jan  3 2017 davejplater@gmail.com
- Update to 1.5.11
- Upstream changes:
  * wxSVGImage: fixed displaying of first video frame
  * added support of EXIF metadata
* Wed Sep  7 2016 davejplater@gmail.com
- Update to 1.5.9
- Upstream changes:
  * changed GetBBox() and GetResultBBox()
  * added some missing header files
* Sun Jun 26 2016 davejplater@gmail.com
- Update to version 1.5.8
- Upstream changes:
  Version 1.5.8 <2016-06-05>
  * fixed ApplyAnimation
  Version 1.5.7 <2016-05-03>
  * wxFfmpegMediaDecoder: added GetChapters() and GetMetadata()
  * fixed SVGAnimationElement
  Version 1.5.6 <2016-03-11>
  * fixed SVGAnimationElement
  Version 1.5.5 <2015-10-03>
  * fixed rendering image element with mask
  * wxFfmpegMediaDecoder: added GetFormatName() and GetCodecTag()
  * wxFfmpegMediaDecoder: fixed wxSVGCanvasVideo
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Sun Apr  5 2015 fisiu@opensuse.org
- Update to 1.5.4:
  * added support of 3-digit hex color codes.
* Tue Mar 10 2015 aloisio@gmx.com
- Update to version 1.5.3 <2015-01-18>
  * applied patch from Sebastian Vater to fix memory leak
- version 1.5.2 <2014-12-14>
  * fixed memory leak (thanks to Sebastian Vater)
- version 1.5.1 <2014-11-23>
  * fixed some compiler errors
* Sat Nov 15 2014 fisiu@opensuse.org
- Update to 1.5:
  * added support of marker element
  * added support of patternTransform attribute
  * added support of stroke-dasharray (1.4.2)
  * fixed handling of preserveAspectRatio="none" (1.4.2)
  * fixed rendering of tspan-element (1.4.1)
  * fixed rendering of use element in pattern and mask elements (1.4.1)
  * added support of pattern element (1.4)
* Fri May 23 2014 fisiu@opensuse.org
- Update to 1.3:
  * added support of animations
  * fixed some GetBBox() methods
  * fixed loading images with relative path (in 1.2.1)
* Sat Sep 21 2013 fisiu@opensuse.org
- Update to 1.2:
  * added initial support of animations
  * added support of mask for image element
  * removed obsolete backends (libart and agg)
  * removed svgui classes
* Thu Sep  5 2013 fisiu@opensuse.org
- Update to 1.1.16:
  * added support of wxProgressDialog
* Tue Jul 23 2013 fisiu@opensuse.org
- Update to 1.1.15:
  * fixed text rendering using PangaCairo.
* Tue Apr  9 2013 fisiu@opensuse.org
- Update to 1.1.14:
  * fixed wxSVGPathSegList::GetValueAsString()
  * fixed wxSVGLengthList::SetValueAsString()
  * fixed rendering of text if text-anchor is set to end
  * fixed rendering of wxSVGCanvasVideo
* Mon Feb 25 2013 fisiu@opensuse.org
- Update to 1.1.13:
  + fixed handling of clipPath element
- Drop wxsvg-libtoolize-fix.patch and use sed instead in spec so
  no need to adjust patch with every DVDStyler update
* Sat Jan 26 2013 fisiu@opensuse.org
- Update to 1.1.12:
  + fixed text rendering using PangaCairo
  + fixed GetPosition() in wxFfmpegMediaDecoder (1.1.10)
- wxsvg-libtoolize-fix.patch updated
* Thu Dec 27 2012 fisiu@opensuse.org
- Use proper Requires for -devel package.
* Thu Dec 13 2012 fisiu@opensuse.org
- Update to 1.1.9:
  + support for ffmpeg 0.11 and libav 0.9
- wxsvg-libtoolize-fix.patch updated
- Fixes since last package version on packman:
  + fixed memory leak and storing xml file
  + fixed rendering of radial gradients
  + fixed handling of aspect ratio of video
  + clipPath element and visibility style property supported
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with newer libtool (12.2)
* Sun Nov 27 2011 detlef@links2linux.de
- new upstream version <1.1.5>
  * wxSVGTextContentElement: added handling of xml:space attribute
  * wxSVGVideoElement: added handling of attributes begin, dur, clipBegin and
    clipEnd
* Thu Nov 17 2011 detlef@links2linux.de
- new upstream version <1.1.3>
  * SVGImageElement: added support of SVG images
  * added support of Gaussian blur filter
* Sat Aug 20 2011 detlef@links2linux.de
- new upstream version <1.1.2>
  * added handling of preserveAspectRatio attribute
* Fri Aug  5 2011 detlef@links2linux.de
- new upstream version <1.1.1>
  * fixed text rendering
  * fixed rendering of video
* Sat Jun 18 2011 detlef@links2linux.de
- new upstream version <1.0.10>
  * fixed wxSVGCanvasImage::Init()
* Sun Feb 27 2011 detlef@links2linux.de
- new upstream version <1.0.8>
  * fixed wxFfmpegMediaDecoder::GetFrameAspectRatio()
* Mon Aug 30 2010 detlef@links2linux.de
- new upstream version <1.0.7.1>
* Sun Aug 29 2010 detlef@links2linux.de
- new upstream version <1.0.6>
  * fixed rendering of video frame
* Fri Jul 23 2010 detlef@links2linux.de
- new upstream version <1.0.5>
  * added possibility to render without preserving aspect ratio.
  * fixed bug in wxSVGCanvasTextFreetype
* Wed Mar 31 2010 detlef@links2linux.de
- new upstream version <1.0.4>
  * fixed memory leak (thanks to Lucian Ion)
* Fri Mar 12 2010 detlef@links2linux.de
- new upstream version <1.0.3>
  * fixed handling of image alpha channel
  * changed to use system expat library
* Sat Jan 30 2010 detlef@links2linux.de
- new upstream version <1.0.2>
* Sat Dec 27 2008 detlef@links2linux.de
- new upstream version <1.0f>
  * added ffmpeg media decoder
  * added support of agg 2.5
  * implemented baseline
  * fixed text-anchor
  * added support of svg gradients
  * implemented GetResultBBox() (SVG1.2)
  * added parameter coordinates (wxSVG_COORDINATES) to GetBBox()
  * fixed text rendering under some platforms
  * implemented saving
  * added GetOwnerDocument()
  * added GetAttribute()
  * fixed CloneNode() and copy constructors
  * added copy constructor to wxSVGPathSegList
  * added rect parameter to wxSVGDocument::Render()
  * wxSVGCtrl: fixed refresh (redraw buffer only in OnPaint)
  * added cairo backend (disabled by default)
  * some other small changes and bug fixes
* Tue Sep 16 2008 detlef@links2linux.de
- new upstream version <1.0b11>
* Wed Apr  2 2008 detlef@links2linux.de
- change to wxWidgets
* Thu Mar  6 2008 detlef@links2linux.de
- new upstream version <1.0b10>
* Mon Jan  7 2008 detlef@links2linux.de
- new upstream version <1.0b8>
* Fri Jan  5 2007 detlef@links2linux.de
- new upstream version
* Thu Jun 15 2006 detlef@links2linux.de
- first build for SUSE (Packman)
* Tue Apr 11 2006 jmartin@mandriva.org
- beta6
- Fixed licence
* Fri Feb  3 2006 austin@mandriva.org
- beta5 + fixes from cvs
* Fri Dec 30 2005 austin@mandriva.org
- initial package
